@@ -481,4 +481,13 @@ container_helptxt = {
     }
 }
 
+
+QDEVICE_HELP_INFO = """  QDevice participates in quorum decisions. With the assistance of 
+  a third-party arbitrator Qnetd, it provides votes so that a cluster 
+  is able to sustain more node failures than standard quorum rules 
+  allow. It is recommended for clusters with an even number of nodes 
+  and highly recommended for 2 node clusters."""
+
+
+SSH_OPTION = "-o StrictHostKeyChecking=no"
 # vim:ts=4:sw=4:et:
