@@ -11,7 +11,6 @@ import socket
 from . import utils
 from . import tmpfiles
 from . import parallax
-from . import bootstrap
 from .msg import err_buf, common_debug
 
 
@@ -19,10 +18,6 @@ def conf():
     return os.getenv('COROSYNC_MAIN_CONFIG_FILE', '/etc/corosync/corosync.conf')
 
 
-def is_corosync_stack():
-    return utils.cluster_stack() == 'corosync'
-
-
 def check_tools():
     return all(utils.is_program(p)
                for p in ['corosync-cfgtool', 'corosync-quorumtool', 'corosync-cmapctl'])
@@ -40,14 +35,16 @@ def query_status(status_type):
     """
     Query status of corosync
 
-    Possible types could be ring/quorum/qnetd
+    Possible types could be ring/quorum/qdevice/qnetd
     """
-    if status_type == "ring":
-        query_ring_status()
-    elif status_type == "quorum":
-        query_quorum_status()
-    elif status_type == "qnetd":
-        query_qnetd_status()
+    status_func_dict = {
+            "ring": query_ring_status,
+            "quorum": query_quorum_status,
+            "qdevice": query_qdevice_status,
+            "qnetd": query_qnetd_status
+            }
+    if status_type in status_func_dict:
+        status_func_dict[status_type]()
     else:
         raise ValueError("Wrong type \"{}\" to query status".format(status_type))
 
@@ -78,6 +75,18 @@ def query_quorum_status():
         print(out)
 
 
+def query_qdevice_status():
+    """
+    Query qdevice status
+    """
+    if not utils.is_qdevice_configured():
+        raise ValueError("QDevice/QNetd not configured!")
+    cmd = "corosync-qdevice-tool -sv"
+    out = utils.get_stdout_or_raise_error(cmd)
+    utils.print_cluster_nodes()
+    print(out)
+
+
 def query_qnetd_status():
     """
     Query qnetd status
@@ -271,9 +280,7 @@ class QDevice(object):
         except socket.error:
             raise ValueError("host \"{}\" is unreachable".format(self.qnetd_addr))
 
-        rc, _ = utils.get_stdout("ping -c 1 {}".format(self.qnetd_addr))
-        if rc != 0:
-            raise ValueError("host \"{}\" is unreachable".format(self.qnetd_addr))
+        utils.ping_node(self.qnetd_addr)
 
         if utils.InterfacesInfo.ip_in_local(qnetd_ip):
             raise ValueError("host for qnetd must be a remote one")
@@ -284,9 +291,15 @@ class QDevice(object):
         if not utils.valid_port(self.port):
             raise ValueError("invalid qdevice port range(1024 - 65535)")
 
-        if self.tie_breaker not in ["lowest", "highest"] and not utils.valid_nodeid(self.tie_breaker):
+        if self.algo not in ("ffsplit", "lms"):
+            raise ValueError("invalid ALGORITHM choice: '{}' (choose from 'ffsplit', 'lms')".format(self.algo))
+
+        if self.tie_breaker not in ("lowest", "highest") and not utils.valid_nodeid(self.tie_breaker):
             raise ValueError("invalid qdevice tie_breaker(lowest/highest/valid_node_id)")
 
+        if self.tls not in ("on", "off", "required"):
+            raise ValueError("invalid TLS choice: '{}' (choose from 'on', 'off', 'required')".format(self.tls))
+
         if self.cmds:
             for cmd in self.cmds.strip(';').split(';'):
                 if not cmd.startswith('/'):
@@ -333,6 +346,7 @@ class QDevice(object):
         self.manage_qnetd("stop")
 
     def debug_and_log_to_bootstrap(self, msg):
+        from . import bootstrap
         common_debug(msg)
         bootstrap.log("# " + msg)
 
@@ -640,11 +654,7 @@ class QDevice(object):
                 cmd_name = re.sub("[.-]", "_", os.path.basename(cmd.split()[0]))
                 exec_name = "exec_{}{}".format(cmd_name, i)
                 p.set('quorum.device.heuristics.{}'.format(exec_name), cmd)
-
-        with open(conf(), 'w') as f:
-            f.write(p.to_string())
-            f.flush()
-            os.fsync(f)
+        utils.str2file(p.to_string(), conf())
 
     def remove_qdevice_config(self):
         """
@@ -653,10 +663,7 @@ class QDevice(object):
         with open(conf()) as f:
             p = Parser(f.read())
             p.remove("quorum.device")
-        with open(conf(), 'w') as f:
-            f.write(p.to_string())
-            f.flush()
-            os.fsync(f)
+        utils.str2file(p.to_string(), conf())
 
     def remove_qdevice_db(self):
         """
@@ -982,9 +989,7 @@ def set_value(path, value):
     f = open(conf()).read()
     p = Parser(f)
     p.set(path, value)
-    f = open(conf(), 'w')
-    f.write(p.to_string())
-    f.close()
+    utils.str2file(p.to_string(), conf())
 
 
 class IPAlreadyConfiguredError(Exception):
@@ -1045,8 +1050,7 @@ def add_node_ucast(ip_list, node_id=None):
     if p.get("quorum.device.model") == "net":
         p.set('quorum.two_node', '0')
 
-    with open(conf(), 'w') as f:
-        f.write(p.to_string())
+    utils.str2file(p.to_string(), conf())
 
 
 def add_node(addr, name=None):
@@ -1094,9 +1098,7 @@ def add_node(addr, name=None):
     if p.get("quorum.device.model") == "net":
         p.set('quorum.two_node', '0')
 
-    f = open(conf(), 'w')
-    f.write(p.to_string())
-    f.close()
+    utils.str2file(p.to_string(), conf())
 
     # update running config (if any)
     if nodes:
@@ -1127,9 +1129,7 @@ def del_node(addr):
     if p.get("quorum.device.model") == "net":
         p.set('quorum.two_node', '0')
 
-    f = open(conf(), 'w')
-    f.write(p.to_string())
-    f.close()
+    utils.str2file(p.to_string(), conf())
 
 
 _COROSYNC_CONF_TEMPLATE_HEAD = """# Please read the corosync.conf.5 manual page
