@@ -13,6 +13,7 @@ from . import completers as compl
 from . import bootstrap
 from . import corosync
 from .cibconfig import cib_factory
+from . import constants
 
 
 class ArgParser(ArgumentParser):
@@ -113,7 +114,7 @@ class Cluster(command.UI):
             if not utils.service_is_active("corosync.service"):
                 err_buf.info("Cluster services already stopped")
                 return
-            if utils.is_qdevice_configured():
+            if utils.service_is_active("corosync-qdevice"):
                 utils.stop_service("corosync-qdevice")
             utils.stop_service("corosync")
             err_buf.info("Cluster services stopped")
@@ -136,7 +137,9 @@ class Cluster(command.UI):
         Enable the cluster services on this node
         '''
         try:
-            utils.enable_service("pacemaker")
+            utils.enable_service("pacemaker.service")
+            if utils.is_qdevice_configured():
+                utils.enable_service("corosync-qdevice.service")
             err_buf.info("Cluster services enabled")
         except IOError as err:
             context.fatal_error(str(err))
@@ -149,7 +152,9 @@ class Cluster(command.UI):
         Disable the cluster services on this node
         '''
         try:
-            utils.disable_service("pacemaker")
+            utils.disable_service("pacemaker.service")
+            if utils.is_qdevice_configured():
+                utils.disable_service("corosync-qdevice.service")
             err_buf.info("Cluster services disabled")
         except IOError as err:
             context.fatal_error(str(err))
@@ -182,38 +187,34 @@ class Cluster(command.UI):
         if len(args) > 0:
             if '--dry-run' in args or looks_like_hostnames(args):
                 args = ['--yes', '--nodes'] + [arg for arg in args if arg != '--dry-run']
-        parser = ArgParser(usage="init [options] [STAGE]", epilog="""
+        parser = ArgParser(description="""
+Initialize a cluster from scratch. This command configures
+a complete cluster, and can also add additional cluster
+nodes to the initial one-node cluster using the --nodes
+option.""", usage="init [options] [STAGE]", epilog="""
 
 Stage can be one of:
     ssh         Create SSH keys for passwordless SSH between cluster nodes
     csync2      Configure csync2
     corosync    Configure corosync
-    storage     Partition shared storage (ocfs2 template only)
     sbd         Configure SBD (requires -s <dev>)
     cluster     Bring the cluster online
+    ocfs2       Configure OCFS2 (requires -o <dev>) NOTE: this is a Technical Preview
     vgfs        Create volume group and filesystem (ocfs2 template only,
-                requires -o <dev>)
+                    requires -o <dev>) NOTE: this stage is an alias of ocfs2 stage
     admin       Create administration virtual IP (optional)
     qdevice     Configure qdevice and qnetd
 
 Note:
   - If stage is not specified, the script will run through each stage
     in sequence, with prompts for required information.
-  - If using the ocfs2 template, the storage stage will partition a block
-    device into two pieces, one for SBD, the remainder for OCFS2.  This is
-    good for testing and demonstration, but not ideal for production.
-    To use storage you have already configured, pass -s and -o to specify
-    the block devices for SBD and OCFS2, and the automatic partitioning
-    will be skipped.
 """, add_help=False, formatter_class=RawDescriptionHelpFormatter)
 
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", action="store_true", dest="quiet",
                             help="Be quiet (don't describe what's happening, just do it)")
         parser.add_argument("-y", "--yes", action="store_true", dest="yes_to_all",
-                            help='Answer "yes" to all prompts (use with caution, this is destructive, especially during the "storage" stage. The /root/.ssh/id_rsa key will be overwritten unless the option "--no-overwrite-sshkey" is used)')
-        parser.add_argument("-t", "--template", dest="template", metavar="TEMPLATE", choices=['ocfs2'],
-                            help='Optionally configure cluster with template "name" (currently only "ocfs2" is valid here)')
+                            help='Answer "yes" to all prompts (use with caution, this is destructive, especially those storage related configurations and stages. The /root/.ssh/id_rsa key will be overwritten unless the option "--no-overwrite-sshkey" is used)')
         parser.add_argument("-n", "--name", metavar="NAME", dest="cluster_name", default="hacluster",
                             help='Set the name of the configured cluster.')
         parser.add_argument("-N", "--nodes", metavar="NODES", dest="nodes",
@@ -222,7 +223,7 @@ Note:
         parser.add_argument("-S", "--enable-sbd", dest="diskless_sbd", action="store_true",
                             help="Enable SBD even if no SBD device is configured (diskless mode)")
         parser.add_argument("-w", "--watchdog", dest="watchdog", metavar="WATCHDOG",
-                            help="Use the given watchdog device")
+                            help="Use the given watchdog device or driver name")
         parser.add_argument("--no-overwrite-sshkey", action="store_true", dest="no_overwrite_sshkey",
                             help='Avoid "/root/.ssh/id_rsa" overwrite if "-y" option is used (False by default)')
 
@@ -239,29 +240,31 @@ Note:
         network_group.add_argument("-I", "--ipv6", action="store_true", dest="ipv6",
                                    help="Configure corosync use IPv6")
 
-        qdevice_group = parser.add_argument_group("QDevice configuration", "Options for configuring QDevice and QNetd.")
+        qdevice_group = parser.add_argument_group("QDevice configuration", re.sub('  ', '', constants.QDEVICE_HELP_INFO) + "\n\nOptions for configuring QDevice and QNetd.")
         qdevice_group.add_argument("--qnetd-hostname", dest="qnetd_addr", metavar="HOST",
                                    help="HOST or IP of the QNetd server to be used")
         qdevice_group.add_argument("--qdevice-port", dest="qdevice_port", metavar="PORT", type=int, default=5403,
-                                   help="TCP PORT of QNetd server(default:5403)")
+                                   help="TCP PORT of QNetd server (default:5403)")
         qdevice_group.add_argument("--qdevice-algo", dest="qdevice_algo", metavar="ALGORITHM", default="ffsplit", choices=['ffsplit', 'lms'],
-                                   help="QNetd decision ALGORITHM(ffsplit/lms, default:ffsplit)")
+                                   help="QNetd decision ALGORITHM (ffsplit/lms, default:ffsplit)")
         qdevice_group.add_argument("--qdevice-tie-breaker", dest="qdevice_tie_breaker", metavar="TIE_BREAKER", default="lowest",
-                                   help="QNetd TIE_BREAKER(lowest/highest/valid_node_id, default:lowest)")
+                                   help="QNetd TIE_BREAKER (lowest/highest/valid_node_id, default:lowest)")
         qdevice_group.add_argument("--qdevice-tls", dest="qdevice_tls", metavar="TLS", default="on", choices=['on', 'off', 'required'],
-                                   help="Whether using TLS on QDevice/QNetd(on/off/required, default:on)")
+                                   help="Whether using TLS on QDevice/QNetd (on/off/required, default:on)")
         qdevice_group.add_argument("--qdevice-heuristics", dest="qdevice_heuristics", metavar="COMMAND",
-                                   help="COMMAND to run with absolute path. For multiple commands, use \";\" to separate(details about heuristics can see man 8 corosync-qdevice)")
+                                   help="COMMAND to run with absolute path. For multiple commands, use \";\" to separate (details about heuristics can see man 8 corosync-qdevice)")
         qdevice_group.add_argument("--qdevice-heuristics-mode", dest="qdevice_heuristics_mode", metavar="MODE", choices=['on', 'sync', 'off'],
-                                   help="MODE of operation of heuristics(on/sync/off, default:sync)")
+                                   help="MODE of operation of heuristics (on/sync/off, default:sync)")
 
         storage_group = parser.add_argument_group("Storage configuration", "Options for configuring shared storage.")
-        storage_group.add_argument("-p", "--partition-device", dest="shared_device", metavar="DEVICE",
-                                   help='Partition this shared storage device (only used in "storage" stage)')
         storage_group.add_argument("-s", "--sbd-device", dest="sbd_devices", metavar="DEVICE", action="append",
                                    help="Block device to use for SBD fencing, use \";\" as separator or -s multiple times for multi path (up to 3 devices)")
-        storage_group.add_argument("-o", "--ocfs2-device", dest="ocfs2_device", metavar="DEVICE",
-                                   help='Block device to use for OCFS2 (only used in "vgfs" stage)')
+        storage_group.add_argument("-o", "--ocfs2-device", dest="ocfs2_devices", metavar="DEVICE", action="append", default=[],
+                help="Block device to use for OCFS2; When using Cluster LVM2 to manage the shared storage, user can specify one or multiple raw disks, use \";\" as separator or -o multiple times for multi path (must specify -C option) NOTE: this is a Technical Preview")
+        storage_group.add_argument("-C", "--cluster-lvm2", action="store_true", dest="use_cluster_lvm2",
+                help="Use Cluster LVM2 (only valid together with -o option) NOTE: this is a Technical Preview")
+        storage_group.add_argument("-m", "--mount-point", dest="mount_point", metavar="MOUNT", default="/srv/clusterfs",
+                help="Mount point for OCFS2 device (default is /srv/clusterfs, only valid together with -o option) NOTE: this is a Technical Preview")
 
         options, args = parse_options(parser, args)
         if options is None or args is None:
@@ -270,6 +273,9 @@ Note:
         stage = ""
         if len(args):
             stage = args[0]
+        if stage == "vgfs":
+            stage = "ocfs2"
+            err_buf.warning("vgfs stage was deprecated and is an alias of ocfs2 stage now")
         if stage not in bootstrap.INIT_STAGES and stage != "":
             parser.error("Invalid stage (%s)" % (stage))
 
@@ -277,18 +283,17 @@ Note:
             if options.qdevice_heuristics_mode and not options.qdevice_heuristics:
                 parser.error("Option --qdevice-heuristics is required if want to configure heuristics mode")
             options.qdevice_heuristics_mode = options.qdevice_heuristics_mode or "sync"
-        elif re.search("--qdevice-.*", ' '.join(sys.argv)) or stage == "qdevice":
+        elif re.search("--qdevice-.*", ' '.join(sys.argv)) or (stage == "qdevice" and options.yes_to_all):
             parser.error("Option --qnetd-hostname is required if want to configure qdevice")
 
-        if options.sbd_devices and options.diskless_sbd:
-            parser.error("Can't use -s and -S options together")
-
         # if options.geo and options.name == "hacluster":
         #    parser.error("For a geo cluster, each cluster must have a unique name (use --name to set)")
         boot_context = bootstrap.Context.set_context(options)
         boot_context.ui_context = context
         boot_context.stage = stage
         boot_context.args = args
+        boot_context.cluster_is_running = utils.service_is_active("pacemaker.service")
+        boot_context.type = "init"
 
         bootstrap.bootstrap_init(boot_context)
 
@@ -311,7 +316,11 @@ Note:
         '''
         Join this node to an existing cluster
         '''
-        parser = ArgParser(usage="join [options] [STAGE]", epilog="""
+        parser = ArgParser(description="""
+Join the current node to an existing cluster. The
+current node cannot be a member of a cluster already.
+Pass any node in the existing cluster as the argument
+to the -c option.""",usage="join [options] [STAGE]", epilog="""
 
 Stage can be one of:
     ssh         Obtain SSH keys from existing cluster node (requires -c <host>)
@@ -344,6 +353,7 @@ If stage is not specified, each stage will be invoked in sequence.
         join_context = bootstrap.Context.set_context(options)
         join_context.ui_context = context
         join_context.stage = stage
+        join_context.type = "join"
 
         bootstrap.bootstrap_join(join_context)
 
@@ -366,7 +376,10 @@ If stage is not specified, each stage will be invoked in sequence.
         Installs packages, sets up corosync and pacemaker, etc.
         Must be executed from a node in the existing cluster.
         '''
-        parser = ArgParser(usage="add [options] [node ...]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
+        parser = ArgParser(description="""
+Add a new node to the cluster. The new node will be
+configured as a cluster member.""",
+                usage="add [options] [node ...]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
         options, args = parse_options(parser, args)
@@ -384,7 +397,14 @@ If stage is not specified, each stage will be invoked in sequence.
         '''
         Remove the given node(s) from the cluster.
         '''
-        parser = ArgParser(usage="remove [options] [<node> ...]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
+        parser = ArgParser(description="""
+Remove one or more nodes from the cluster.
+
+This command can remove the last node in the cluster,
+thus effectively removing the whole cluster. To remove
+the last node, pass --force argument to crm or set
+the config.core.force option.""",
+                usage="remove [options] [<node> ...]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
@@ -463,7 +483,13 @@ If stage is not specified, each stage will be invoked in sequence.
         * arbitrator IP / hostname (optional)
         * list of tickets (can be empty)
         '''
-        parser = ArgParser(usage="geo-init [options]", epilog="""
+        parser = ArgParser(description="""
+Create a new geo cluster with the current cluster as the
+first member. Pass the complete geo cluster topology as
+arguments to this command, and then use geo-join and
+geo-init-arbitrator to add the remaining members to
+the geo cluster.""",
+        usage="geo-init [options]", epilog="""
 
 Cluster Description
 
@@ -520,7 +546,17 @@ Cluster Description
         '''
         Join this cluster to a geo configuration.
         '''
-        parser = ArgParser(usage="geo-join [options]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
+        parser = ArgParser(description="""
+This command should be run from one of the nodes in a cluster
+which is currently not a member of a geo cluster. The geo
+cluster configuration will be fetched from the provided node,
+and the cluster will be added to the geo cluster.
+
+Note that each cluster in a geo cluster needs to have a unique
+name set. The cluster name can be set using the --name argument
+to init, or by configuring corosync with the cluster name in
+an existing cluster.""",
+                usage="geo-join [options]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
@@ -554,7 +590,11 @@ Cluster Description
         '''
         Make this node a geo arbitrator.
         '''
-        parser = ArgParser(usage="geo-init-arbitrator [options]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
+        parser = ArgParser(description="""
+Configure the current node as a geo arbitrator. The command
+requires an existing geo cluster or geo arbitrator from which
+to get the geo cluster configuration.""",
+                usage="geo-init-arbitrator [options]", add_help=False, formatter_class=RawDescriptionHelpFormatter)
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
@@ -587,26 +627,21 @@ Cluster Description
         '''
         Quick cluster health status. Corosync status, DRBD status...
         '''
-
-        stack = utils.cluster_stack()
-        if not stack:
-            err_buf.error("No supported cluster stack found (tried heartbeat|openais|corosync)")
-        if utils.cluster_stack() == 'corosync':
-            print("Name: {}\n".format(get_cluster_name()))
-            print("Services:")
-            for svc in ["corosync", "pacemaker"]:
-                info = utils.service_info(svc)
-                if info:
-                    print("%-16s %s" % (svc, info))
-                else:
-                    print("%-16s unknown" % (svc))
-
-            rc, outp = utils.get_stdout(['corosync-cfgtool', '-s'], shell=False)
-            if rc == 0:
-                print("")
-                print(outp)
+        print("Name: {}\n".format(get_cluster_name()))
+        print("Services:")
+        for svc in ["corosync", "pacemaker"]:
+            info = utils.service_info(svc)
+            if info:
+                print("%-16s %s" % (svc, info))
             else:
-                print("Failed to get corosync status")
+                print("%-16s unknown" % (svc))
+
+        rc, outp = utils.get_stdout(['corosync-cfgtool', '-s'], shell=False)
+        if rc == 0:
+            print("")
+            print(outp)
+        else:
+            print("Failed to get corosync status")
 
     @command.completers_repeating(compl.choice(['10', '60', '600']))
     def do_wait_for_startup(self, context, timeout='10'):
@@ -689,3 +724,12 @@ Cluster Description
             utils.remote_diff_this(filename, nodes, this_node)
         elif len(nodes):
             utils.remote_diff(filename, nodes)
+
+    def do_crash_test(self, context, *args):
+        """
+        """
+        from .crash_test import main
+        sys.argv[1:] = args
+        main.ctx.process_name = context.command_name
+        main.run(main.ctx)
+        return True
