@@ -250,13 +250,6 @@ class NodeMgmt(command.UI):
                 return False
         return True
 
-    @command.completers(compl.nodes)
-    def do_status(self, context, node=None):
-        'usage: status [<node>]'
-        a = node and ('--xpath "//nodes/node[@uname=\'%s\']"' % node) or \
-            '-o nodes'
-        return utils.ext_cmd("%s %s" % (xmlutil.cib_dump, a)) == 0
-
     @command.alias('list')
     @command.completers(compl.nodes)
     def do_show(self, context, node=None):
@@ -387,21 +380,18 @@ class NodeMgmt(command.UI):
     def _call_delnode(self, node):
         "Remove node (how depends on cluster stack)"
         rc = True
-        if utils.cluster_stack() == "heartbeat":
-            cmd = (self.hb_delnode % node)
+        ec, s = utils.get_stdout("%s -p" % self.crm_node)
+        if not s:
+            common_err('%s -p could not list any nodes (rc=%d)' %
+                       (self.crm_node, ec))
+            rc = False
         else:
-            ec, s = utils.get_stdout("%s -p" % self.crm_node)
-            if not s:
-                common_err('%s -p could not list any nodes (rc=%d)' %
-                           (self.crm_node, ec))
+            partition_l = s.split()
+            if node in partition_l:
+                common_err("according to %s, node %s is still active" %
+                           (self.crm_node, node))
                 rc = False
-            else:
-                partition_l = s.split()
-                if node in partition_l:
-                    common_err("according to %s, node %s is still active" %
-                               (self.crm_node, node))
-                    rc = False
-            cmd = "%s --force -R %s" % (self.crm_node, node)
+        cmd = "%s --force -R %s" % (self.crm_node, node)
         if not rc:
             if config.core.force:
                 common_info('proceeding with node %s removal' % node)
