@@ -16,7 +16,11 @@ import fnmatch
 import gc
 import ipaddress
 import argparse
+import random
+import string
+from pathlib import Path
 from contextlib import contextmanager, closing
+from stat import S_ISBLK
 from . import config
 from . import userdir
 from . import constants
@@ -24,6 +28,13 @@ from . import options
 from . import term
 from . import parallax
 from .msg import common_warn, common_info, common_debug, common_err, err_buf
+from .constants import SSH_OPTION
+
+
+class TerminateSubCommand(Exception):
+    """
+    This is an exception to jump out of subcommand when meeting errors while staying interactive shell
+    """
 
 
 def to_ascii(input_str):
@@ -344,6 +355,15 @@ def add_sudo(cmd):
     return cmd
 
 
+def add_su(cmd, user):
+    """
+    Wrapped cmd with su -c "<cmd>" <user>
+    """
+    if user == "root":
+        return cmd
+    return "su -c \"{}\" {}".format(cmd, user)
+
+
 def chown(path, user, group):
     if isinstance(user, int):
         uid = user
@@ -508,13 +528,14 @@ def open_atomic(filepath, mode="r", buffering=-1, fsync=False, encoding=None):
         os.rename(tmppath, filepath)
 
 
-def str2file(s, fname):
+def str2file(s, fname, mod=0o644):
     '''
     Write a string to a file.
     '''
     try:
-        with open_atomic(fname, 'w', encoding='utf-8') as dst:
+        with open_atomic(fname, 'w', encoding='utf-8', fsync=True) as dst:
             dst.write(to_ascii(s))
+        os.chmod(fname, mod)
     except IOError as msg:
         common_err(msg)
         return False
@@ -568,14 +589,14 @@ def safe_close_w(f):
 
 
 def is_path_sane(name):
-    if re.search(r"['`#*?$\[\]]", name):
+    if re.search(r"['`#*?$\[\];]", name):
         common_err("%s: bad path" % name)
         return False
     return True
 
 
 def is_filename_sane(name):
-    if re.search(r"['`/#*?$\[\]]", name):
+    if re.search(r"['`/#*?$\[\];]", name):
         common_err("%s: bad filename" % name)
         return False
     return True
@@ -704,10 +725,11 @@ def lock(lockdir):
             rmdir_r(os.path.join(lockdir, _LOCKDIR))
 
 
-def mkdirp(d, mode=0o777):
-    if os.path.isdir(d):
-        return True
-    os.makedirs(d, mode=mode)
+def mkdirp(directory, mode=0o777, parents=True, exist_ok=True):
+    """
+    Same behavior as the POSIX mkdir -p command
+    """
+    Path(directory).mkdir(mode, parents, exist_ok)
 
 
 def pipe_cmd_nosudo(cmd):
@@ -1087,17 +1109,6 @@ def print_stacktrace():
     traceback.print_stack(sf)
 
 
-@memoize
-def cluster_stack():
-    if is_process("heartbeat:.[m]aster"):
-        return "heartbeat"
-    elif is_process("[a]isexec"):
-        return "openais"
-    elif os.path.exists("/etc/corosync/corosync.conf") or is_program('corosync-cfgtool'):
-        return "corosync"
-    return ""
-
-
 def edit_file(fname):
     'Edit a file.'
     if not fname:
@@ -2084,12 +2095,13 @@ def get_iplist_corosync_using():
     return re.findall(r'id\s*=\s*(.*)', out)
 
 
-def check_ssh_passwd_need(host):
+def check_ssh_passwd_need(host, user="root"):
     """
     Check whether access to host need password
     """
     ssh_options = "-o StrictHostKeyChecking=no -o EscapeChar=none -o ConnectTimeout=15"
     ssh_cmd = "ssh {} -T -o Batchmode=yes {} true".format(ssh_options, host)
+    ssh_cmd = add_su(ssh_cmd, user)
     rc, _, _ = get_stdout_stderr(ssh_cmd)
     return rc != 0
 
@@ -2330,9 +2342,11 @@ class InterfacesInfo(object):
         # 2: enp1s0    inet 192.168.122.241/24 brd 192.168.122.255 scope global enp1s0\       valid_lft forever preferred_lft forever
         for line in out.splitlines():
             _, nic, _, ip_with_mask, *_ = line.split()
-            #TODO change this condition when corosync support link-local address
+            # maybe from tun interface
+            if not '/' in ip_with_mask:
+                continue
             interface_inst = Interface(ip_with_mask)
-            if interface_inst.is_loopback or interface_inst.is_link_local:
+            if interface_inst.is_loopback:
                 continue
             # one nic might configured multi IP addresses
             if nic not in self._nic_info_dict:
@@ -2622,13 +2636,248 @@ def package_is_installed(pkg, remote_addr=None):
     return rc == 0
 
 
-@contextmanager
-def disable_exception_traceback():
+def ping_node(node):
     """
-    All traceback information is suppressed and only the exception type and value are printed
+    Check if the remote node is reachable
     """
-    default_value = getattr(sys, "tracebacklimit", 1000)  # `1000` is a Python's default value
-    sys.tracebacklimit = 0
-    yield
-    sys.tracebacklimit = default_value  # revert changes
+    rc, _, err = get_stdout_stderr("ping -c 1 {}".format(node))
+    if rc != 0:
+        raise ValueError("host \"{}\" is unreachable: {}".format(node, err))
+
+
+def is_quorate(expected_votes, actual_votes):
+    """
+    Given expected votes and actual votes, calculate if is quorated
+    """
+    return int(actual_votes)/int(expected_votes) > 0.5
+
+
+def get_stdout_or_raise_error(cmd, remote=None, success_val=0):
+    """
+    Common function to get stdout from cmd or raise exception
+    """
+    if remote:
+        cmd = "ssh {} root@{} \"{}\"".format(SSH_OPTION, remote, cmd)
+    rc, out, err = get_stdout_stderr(cmd)
+    if rc != success_val:
+        raise ValueError("Failed to run \"{}\": {}".format(cmd, err))
+    return out
+
+
+def get_quorum_votes_dict(remote=None):
+    """
+    Return a dictionary which contain expect votes and total votes
+    """
+    out = get_stdout_or_raise_error("corosync-quorumtool -s", remote=remote)
+    return dict(re.findall("(Expected|Total) votes:\s+(\d+)", out))
+
+
+def has_resource_running(ra_type=None):
+    """
+    Check if any RA is running
+    """
+    out = get_stdout_or_raise_error("crm_mon -1")
+    if ra_type:
+        return re.search("{}.*Started".format(ra_type), out) is not None
+    else:
+        return re.search("No active resources", out) is None
+
+
+def has_resource_configured(ra_type, peer=None):
+    """
+    Check if the RA configured
+    """
+    out = get_stdout_or_raise_error("crm_mon -1rR", remote=peer)
+    return re.search(ra_type, out) is not None
+
+
+def check_all_nodes_reachable():
+    """
+    Check if all cluster nodes are reachable
+    """
+    out = get_stdout_or_raise_error("crm_node -l")
+    for node in re.findall("\d+ (.*) \w+", out):
+        ping_node(node)
+
+
+def re_split_string(reg, string):
+    """
+    Split a string by a regrex, filter out empty items
+    """
+    return [x for x in re.split(reg, string) if x]
+
+
+def is_block_device(dev):
+    """
+    Check if dev is a block device
+    """
+    try:
+        rc = S_ISBLK(os.stat(dev).st_mode)
+    except OSError:
+        return False
+    return rc
+
+
+def has_stonith_running():
+    """
+    Check if any stonith device registered
+    """
+    out = get_stdout_or_raise_error("stonith_admin -L")
+    return re.search("[1-9]+ fence device[s]* found", out) is not None
+
+
+def parse_append_action_argument(input_list, parse_re="[; ]"):
+    """
+    Parse append action argument into a list, like:
+      -s "/dev/sdb1;/dev/sdb2"
+      -s /dev/sdb1 -s /dev/sbd2
+
+      Both return ["/dev/sdb1", "/dev/sdb2"]
+    """
+    result_list = []
+    for item in input_list:
+        result_list += re_split_string(parse_re, item)
+    return result_list
+
+
+def has_disk_mounted(dev):
+    """
+    Check if device already mounted
+    """
+    out = get_stdout_or_raise_error("mount")
+    return re.search("\n{} on ".format(dev), out) is not None
+
+
+def has_mount_point_used(directory):
+    """
+    Check if mount directory already mounted
+    """
+    out = get_stdout_or_raise_error("mount")
+    return re.search(" on {}".format(directory), out) is not None
+
+
+def all_exist_id():
+    """
+    Get current exist id list
+    """
+    from .cibconfig import cib_factory
+    cib_factory.refresh()
+    return cib_factory.id_list()
+
+
+def randomword(length=6):
+    """
+    Generate random word
+    """
+    letters = string.ascii_lowercase
+    return ''.join(random.choice(letters) for i in range(length))
+
+
+def gen_unused_id(exist_id_list, prefix="", length=6):
+    """
+    Generate unused id
+    """
+    unused_id = prefix or randomword(length)
+    while unused_id in exist_id_list:
+        unused_id = re.sub("$", "-{}".format(randomword(length)), unused_id)
+    return unused_id
+
+
+def get_all_vg_name():
+    """
+    Get all available VGs
+    """
+    out = get_stdout_or_raise_error("vgdisplay")
+    return re.findall("VG Name\s+(.*)", out)
+
+
+def get_pe_number(vg_id):
+    """
+    Get pe number
+    """
+    output = get_stdout_or_raise_error("vgdisplay {}".format(vg_id))
+    res = re.search("Total PE\s+(\d+)", output)
+    if not res:
+        raise ValueError("Cannot find PE on VG({})".format(vg_id))
+    return int(res.group(1))
+
+
+def has_dev_partitioned(dev, peer=None):
+    """
+    Check if device has partitions
+    """
+    return len(get_dev_info(dev, "NAME", peer=peer).splitlines()) > 1
+
+
+def get_dev_uuid(dev, peer=None):
+    """
+    Get UUID of device on local or peer node
+    """
+    out = get_dev_info(dev, "UUID", peer=peer).splitlines()
+    return out[0] if out else get_dev_uuid_2(dev, peer)
+
+
+def get_dev_uuid_2(dev, peer=None):
+    """
+    Get UUID of device using blkid
+    """
+    out = get_stdout_or_raise_error("blkid {}".format(dev), remote=peer)
+    res = re.search("UUID=\"(.*?)\"", out)
+    return res.group(1) if res else None
+
+
+def get_dev_fs_type(dev, peer=None):
+    """
+    Get filesystem type of device
+    """
+    return get_dev_info(dev, "FSTYPE", peer=peer)
+
+
+def get_dev_info(dev, *_type, peer=None):
+    """
+    Get device info using lsblk
+    """
+    cmd = "lsblk -fno {} {}".format(','.join(_type), dev)
+    return get_stdout_or_raise_error(cmd, remote=peer)
+
+
+def is_dev_used_for_lvm(dev, peer=None):
+    """
+    Check if device is LV
+    """
+    return get_dev_info(dev, "TYPE", peer=peer) == "lvm"
+
+
+def compare_uuid_with_peer_dev(dev_list, peer):
+    """
+    Check if device UUID is the same with peer's device
+    """
+    for dev in dev_list:
+        local_uuid = get_dev_uuid(dev)
+        if not local_uuid:
+            raise ValueError("Cannot find UUID for {} on local".format(dev))
+        peer_uuid = get_dev_uuid(dev, peer)
+        if not peer_uuid:
+            raise ValueError("Cannot find UUID for {} on {}".format(dev, peer))
+        if local_uuid != peer_uuid:
+            raise ValueError("UUID of {} not same with peer {}".format(dev, peer))
+
+
+def append_res_to_group(group_id, res_id):
+    """
+    Append resource to exist group
+    """
+    cmd = "crm configure modgroup {} add {}".format(group_id, res_id)
+    get_stdout_or_raise_error(cmd)
+
+
+def get_qdevice_sync_timeout():
+    """
+    Get qdevice sync_timeout
+    """
+    out = get_stdout_or_raise_error("crm corosync status qdevice")
+    res = re.search("Sync HB interval:\s+(\d+)ms", out)
+    if not res:
+        raise ValueError("Cannot find qdevice sync timeout")
+    return int(int(res.group(1))/1000)
 # vim:ts=4:sw=4:et:
