@@ -1521,14 +1521,12 @@ def stdchannel_redirected(stdchannel, dest_filename):
 
 def start_slave_collector(node, arg_str):
     if node == constants.WE:
-        cmd = r"hb_report __slave".format(os.getcwd())
+        cmd = r"/usr/sbin/hb_report __slave".format(os.getcwd())
         for item in arg_str.split():
             cmd += " {}".format(str(item))
         _, out = crmutils.get_stdout(cmd)
     else:
-        cmd = r'ssh {} {} "{} hb_report __slave"'.\
-              format(constants.SSH_OPTS, node,
-                     constants.SUDO, os.getcwd())
+        cmd = r'ssh {} {} "/usr/sbin/hb_report __slave"'.format(constants.SSH_OPTS, node, os.getcwd())
         for item in arg_str.split():
             cmd += " {}".format(str(item))
         code, out, err = crmutils.get_stdout_stderr(cmd)
@@ -1643,12 +1641,39 @@ def dump_D_process():
     return out_string
 
 
+def lsof_ocfs2_device():
+    """
+    List open files for OCFS2 device
+    """
+    out_string = ""
+    _, out, _ = crmutils.get_stdout_stderr("mount")
+    dev_list = re.findall("\n(.*) on .* type ocfs2 ", out)
+    for dev in dev_list:
+        cmd = "lsof {}".format(dev)
+        out_string += "\n\n#=====[ Command ] ==========================#\n"
+        out_string += "# {}\n".format(cmd)
+        _, cmd_out, _ = crmutils.get_stdout_stderr(cmd)
+        if cmd_out:
+            out_string += cmd_out
+    return out_string
+
+
 def dump_ocfs2():
     ocfs2_f = os.path.join(constants.WORKDIR, constants.OCFS2_F)
     with open(ocfs2_f, "w") as f:
-        f.write(dump_D_process())
+        rc, out, err = crmutils.get_stdout_stderr("mounted.ocfs2 -d")
+        if rc != 0:
+            f.write("Failed to run \"mounted.ocfs2 -d\": {}".format(err))
+            return
+        # No ocfs2 device, just header line printed
+        elif len(out.split('\n')) == 1:
+            f.write("No ocfs2 partitions found")
+            return
 
-        cmds = [ "dmesg",  "ps -efL", "lsof",
+        f.write(dump_D_process())
+        f.write(lsof_ocfs2_device())
+
+        cmds = [ "dmesg",  "ps -efL",
                 "lsblk -o 'NAME,KNAME,MAJ:MIN,FSTYPE,LABEL,RO,RM,MODEL,SIZE,OWNER,GROUP,MODE,ALIGNMENT,MIN-IO,OPT-IO,PHY-SEC,LOG-SEC,ROTA,SCHED,MOUNTPOINT'",
                 "mounted.ocfs2 -f", "findmnt", "mount",
                 "cat /sys/fs/ocfs2/cluster_stack"
