@@ -55,16 +55,19 @@ optional arguments:
 
 CRM_CLUSTER_INIT_H_OUTPUT = '''usage: init [options] [STAGE]
 
+Initialize a cluster from scratch. This command configures
+a complete cluster, and can also add additional cluster
+nodes to the initial one-node cluster using the --nodes
+option.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
   -y, --yes             Answer "yes" to all prompts (use with caution, this is
-                        destructive, especially during the "storage" stage.
-                        The /root/.ssh/id_rsa key will be overwritten unless
-                        the option "--no-overwrite-sshkey" is used)
-  -t TEMPLATE, --template TEMPLATE
-                        Optionally configure cluster with template "name"
-                        (currently only "ocfs2" is valid here)
+                        destructive, especially those storage related
+                        configurations and stages. The /root/.ssh/id_rsa key
+                        will be overwritten unless the option "--no-overwrite-
+                        sshkey" is used)
   -n NAME, --name NAME  Set the name of the configured cluster.
   -N NODES, --nodes NODES
                         Additional nodes to add to the created cluster. May
@@ -73,7 +76,7 @@ optional arguments:
   -S, --enable-sbd      Enable SBD even if no SBD device is configured
                         (diskless mode)
   -w WATCHDOG, --watchdog WATCHDOG
-                        Use the given watchdog device
+                        Use the given watchdog device or driver name
   --no-overwrite-sshkey
                         Avoid "/root/.ssh/id_rsa" overwrite if "-y" option is
                         used (False by default)
@@ -94,65 +97,77 @@ Network configuration:
   -I, --ipv6            Configure corosync use IPv6
 
 QDevice configuration:
+  QDevice participates in quorum decisions. With the assistance of 
+  a third-party arbitrator Qnetd, it provides votes so that a cluster 
+  is able to sustain more node failures than standard quorum rules 
+  allow. It is recommended for clusters with an even number of nodes 
+  and highly recommended for 2 node clusters.
+  
   Options for configuring QDevice and QNetd.
 
   --qnetd-hostname HOST
                         HOST or IP of the QNetd server to be used
-  --qdevice-port PORT   TCP PORT of QNetd server(default:5403)
+  --qdevice-port PORT   TCP PORT of QNetd server (default:5403)
   --qdevice-algo ALGORITHM
-                        QNetd decision ALGORITHM(ffsplit/lms, default:ffsplit)
+                        QNetd decision ALGORITHM (ffsplit/lms,
+                        default:ffsplit)
   --qdevice-tie-breaker TIE_BREAKER
-                        QNetd TIE_BREAKER(lowest/highest/valid_node_id,
+                        QNetd TIE_BREAKER (lowest/highest/valid_node_id,
                         default:lowest)
-  --qdevice-tls TLS     Whether using TLS on QDevice/QNetd(on/off/required,
+  --qdevice-tls TLS     Whether using TLS on QDevice/QNetd (on/off/required,
                         default:on)
   --qdevice-heuristics COMMAND
                         COMMAND to run with absolute path. For multiple
-                        commands, use ";" to separate(details about heuristics
-                        can see man 8 corosync-qdevice)
+                        commands, use ";" to separate (details about
+                        heuristics can see man 8 corosync-qdevice)
   --qdevice-heuristics-mode MODE
-                        MODE of operation of heuristics(on/sync/off,
+                        MODE of operation of heuristics (on/sync/off,
                         default:sync)
 
 Storage configuration:
   Options for configuring shared storage.
 
-  -p DEVICE, --partition-device DEVICE
-                        Partition this shared storage device (only used in
-                        "storage" stage)
   -s DEVICE, --sbd-device DEVICE
                         Block device to use for SBD fencing, use ";" as
                         separator or -s multiple times for multi path (up to 3
                         devices)
   -o DEVICE, --ocfs2-device DEVICE
-                        Block device to use for OCFS2 (only used in "vgfs"
-                        stage)
+                        Block device to use for OCFS2; When using Cluster LVM2
+                        to manage the shared storage, user can specify one or
+                        multiple raw disks, use ";" as separator or -o
+                        multiple times for multi path (must specify -C option)
+                        NOTE: this is a Technical Preview
+  -C, --cluster-lvm2    Use Cluster LVM2 (only valid together with -o option)
+                        NOTE: this is a Technical Preview
+  -m MOUNT, --mount-point MOUNT
+                        Mount point for OCFS2 device (default is
+                        /srv/clusterfs, only valid together with -o option)
+                        NOTE: this is a Technical Preview
 
 Stage can be one of:
     ssh         Create SSH keys for passwordless SSH between cluster nodes
     csync2      Configure csync2
     corosync    Configure corosync
-    storage     Partition shared storage (ocfs2 template only)
     sbd         Configure SBD (requires -s <dev>)
     cluster     Bring the cluster online
+    ocfs2       Configure OCFS2 (requires -o <dev>) NOTE: this is a Technical Preview
     vgfs        Create volume group and filesystem (ocfs2 template only,
-                requires -o <dev>)
+                    requires -o <dev>) NOTE: this stage is an alias of ocfs2 stage
     admin       Create administration virtual IP (optional)
     qdevice     Configure qdevice and qnetd
 
 Note:
   - If stage is not specified, the script will run through each stage
-    in sequence, with prompts for required information.
-  - If using the ocfs2 template, the storage stage will partition a block
-    device into two pieces, one for SBD, the remainder for OCFS2.  This is
-    good for testing and demonstration, but not ideal for production.
-    To use storage you have already configured, pass -s and -o to specify
-    the block devices for SBD and OCFS2, and the automatic partitioning
-    will be skipped.'''
+    in sequence, with prompts for required information.'''
 
 
 CRM_CLUSTER_JOIN_H_OUTPUT = '''usage: join [options] [STAGE]
 
+Join the current node to an existing cluster. The
+current node cannot be a member of a cluster already.
+Pass any node in the existing cluster as the argument
+to the -c option.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
@@ -181,6 +196,9 @@ If stage is not specified, each stage will be invoked in sequence.'''
 
 CRM_CLUSTER_ADD_H_OUTPUT = '''usage: add [options] [node ...]
 
+Add a new node to the cluster. The new node will be
+configured as a cluster member.
+
 optional arguments:
   -h, --help  Show this help message
   -y, --yes   Answer "yes" to all prompts (use with caution)'''
@@ -188,6 +206,13 @@ optional arguments:
 
 CRM_CLUSTER_REMOVE_H_OUTPUT = '''usage: remove [options] [<node> ...]
 
+Remove one or more nodes from the cluster.
+
+This command can remove the last node in the cluster,
+thus effectively removing the whole cluster. To remove
+the last node, pass --force argument to crm or set
+the config.core.force option.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
@@ -201,6 +226,12 @@ optional arguments:
 
 CRM_CLUSTER_GEO_INIT_H_OUTPUT = '''usage: geo-init [options]
 
+Create a new geo cluster with the current cluster as the
+first member. Pass the complete geo cluster topology as
+arguments to this command, and then use geo-join and
+geo-init-arbitrator to add the remaining members to
+the geo cluster.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
@@ -229,6 +260,16 @@ Cluster Description
 
 CRM_CLUSTER_GEO_JOIN_H_OUTPUT = '''usage: geo-join [options]
 
+This command should be run from one of the nodes in a cluster
+which is currently not a member of a geo cluster. The geo
+cluster configuration will be fetched from the provided node,
+and the cluster will be added to the geo cluster.
+
+Note that each cluster in a geo cluster needs to have a unique
+name set. The cluster name can be set using the --name argument
+to init, or by configuring corosync with the cluster name in
+an existing cluster.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
@@ -242,6 +283,10 @@ optional arguments:
 
 CRM_CLUSTER_GEO_INIT_ARBIT_H_OUTPUT = '''usage: geo-init-arbitrator [options]
 
+Configure the current node as a geo arbitrator. The command
+requires an existing geo cluster or geo arbitrator from which
+to get the geo cluster configuration.
+
 optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
