@@ -47,6 +47,16 @@ def step_impl(context, cmd, addr):
     context.stdout = out
 
 
+@then('Print stdout')
+def step_impl(context):
+    context.logger.info("\n{}".format(context.stdout))
+
+
+@then('Print stderr')
+def step_impl(context):
+    context.logger.info("\n{}".format(context.command_error_output))
+
+
 @when('Try "{cmd}" on "{addr}"')
 def step_impl(context, cmd, addr):
     run_command_local_or_remote(context, cmd, addr, err_record=True)
@@ -101,7 +111,7 @@ def step_impl(context, msg):
 
 @then('Except "{msg}"')
 def step_impl(context, msg):
-    assert context.command_error_output == msg
+    assert msg in context.command_error_output
     context.command_error_output = None
 
 
@@ -204,9 +214,9 @@ def step_impl(context, res, res_type, state):
     result = None
     while try_count < 5:
         time.sleep(1)
-        _, out = run_command(context, "crm_mon -1")
+        _, out = run_command(context, "crm_mon -1rR")
         if out:
-            result = re.search(r'\s{}\s+.*:{}\):\s+{} '.format(res, res_type, state), out)
+            result = re.search(r'\s{}\s+.*:+{}\):\s+{} '.format(res, res_type, state), out)
             if not result:
                 try_count += 1
             else:
@@ -278,3 +288,10 @@ def step_impl(context, f, archive):
 @then('File "{f}" not in "{archive}"')
 def step_impl(context, f, archive):
     assert file_in_archive(f, archive) is False
+
+
+@then('File "{f}" was synced in cluster')
+def step_impl(context, f):
+    cmd = "crm cluster diff {}".format(f)
+    rc, out = run_command(context, cmd)
+    assert out == ""
