@@ -53,7 +53,7 @@ def run_command_local_or_remote(context, cmd, addr, err_record=False):
         return out
     else:
         try:
-            results = parallax.parallax_call([addr], cmd)
+            results = parallax.parallax_call(addr.split(','), cmd)
         except ValueError as err:
             if err_record:
                 context.command_error_output = str(err)
