@@ -1,27 +1,27 @@
+from __future__ import print_function
+from __future__ import unicode_literals
 # Copyright (C) 2014 Kristoffer Gronlund <kgronlund@suse.com>
 # See COPYING for license information.
 
 
 from crmsh import cibconfig
 from lxml import etree
-from nose.tools import eq_, with_setup
 from crmsh import xmlutil
 
 factory = cibconfig.cib_factory
 
 
-def setup_func():
+def setup_function():
     "set up test fixtures"
     from crmsh import idmgmt
     idmgmt.clear()
     factory._push_state()
 
 
-def teardown_func():
+def teardown_function():
     factory._pop_state()
 
 
-@with_setup(setup_func, teardown_func)
 def test_bug41660_1():
     xml = """<primitive id="bug41660" class="ocf" provider="pacemaker" type="Dummy"> \
     <meta_attributes id="bug41660-meta"> \
@@ -31,9 +31,9 @@ def test_bug41660_1():
 """
     data = etree.fromstring(xml)
     obj = factory.create_from_node(data)
-    print etree.tostring(obj.node)
+    print(etree.tostring(obj.node))
     data = obj.repr_cli(format_mode=-1)
-    print data
+    print(data)
     exp = 'primitive bug41660 ocf:pacemaker:Dummy meta target-role=Stopped'
     assert data == exp
     assert obj.cli_use_validate()
@@ -43,13 +43,11 @@ def test_bug41660_1():
         factory.commit = lambda *args: True
         from crmsh.ui_resource import set_deep_meta_attr
         set_deep_meta_attr("bug41660", "target-role", "Started")
-        eq_(['Started'],
-            obj.node.xpath('.//nvpair[@name="target-role"]/@value'))
+        assert ['Started'] == obj.node.xpath('.//nvpair[@name="target-role"]/@value')
     finally:
         factory.commit = commit_holder
 
 
-@with_setup(setup_func, teardown_func)
 def test_bug41660_2():
     xml = """
 <clone id="libvirtd-clone">
@@ -77,22 +75,20 @@ def test_bug41660_2():
     #assert data == exp
     #assert obj.cli_use_validate()
 
-    print etree.tostring(obj.node)
+    print(etree.tostring(obj.node))
 
     commit_holder = factory.commit
     try:
         factory.commit = lambda *args: True
         from crmsh.ui_resource import set_deep_meta_attr
-        print "PRE", etree.tostring(obj.node)
+        print("PRE", etree.tostring(obj.node))
         set_deep_meta_attr("libvirtd-clone", "target-role", "Started")
-        print "POST", etree.tostring(obj.node)
-        eq_(['Started'],
-            obj.node.xpath('.//nvpair[@name="target-role"]/@value'))
+        print("POST", etree.tostring(obj.node))
+        assert ['Started'] == obj.node.xpath('.//nvpair[@name="target-role"]/@value')
     finally:
         factory.commit = commit_holder
 
 
-@with_setup(setup_func, teardown_func)
 def test_bug41660_3():
     xml = """
 <clone id="libvirtd-clone">
@@ -113,7 +109,7 @@ def test_bug41660_3():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print data
+    print(data)
     exp = 'clone libvirtd-clone libvirtd meta target-role=Stopped'
     assert data == exp
     assert obj.cli_use_validate()
@@ -123,13 +119,11 @@ def test_bug41660_3():
         factory.commit = lambda *args: True
         from crmsh.ui_resource import set_deep_meta_attr
         set_deep_meta_attr("libvirtd-clone", "target-role", "Started")
-        eq_(['Started'],
-            obj.node.xpath('.//nvpair[@name="target-role"]/@value'))
+        assert ['Started'] == obj.node.xpath('.//nvpair[@name="target-role"]/@value')
     finally:
         factory.commit = commit_holder
 
 
-@with_setup(setup_func, teardown_func)
 def test_comments():
     xml = """<cib epoch="25" num_updates="1" admin_epoch="0" validate-with="pacemaker-1.2" cib-last-written="Thu Mar  6 15:53:49 2014" update-origin="beta1" update-client="cibadmin" update-user="root" crm_feature_set="3.0.8" have-quorum="1" dc-uuid="1">
   <configuration>
@@ -170,10 +164,9 @@ def test_comments():
 </cib>"""
     elems = etree.fromstring(xml)
     xmlutil.sanitize_cib(elems)
-    assert etree.tostring(elems).count("COMMENT TEXT") == 3
+    assert xmlutil.xml_tostring(elems).count("COMMENT TEXT") == 3
 
 
-@with_setup(setup_func, teardown_func)
 def test_eq1():
     xml1 = """<cluster_property_set id="cib-bootstrap-options">
     <nvpair id="cib-bootstrap-options-stonith-enabled" name="stonith-enabled" value="true"></nvpair>
@@ -204,7 +197,6 @@ def test_eq1():
     assert xmlutil.xml_equals(e1, e2, show=True)
 
 
-@with_setup(setup_func, teardown_func)
 def test_pcs_interop_1():
     """
     pcs<>crmsh interop bug
@@ -224,16 +216,15 @@ def test_pcs_interop_1():
 
     assert len(elem.xpath(".//meta_attributes/nvpair[@name='target-role']")) == 1
 
-    print "BEFORE:", etree.tostring(elem)
+    print("BEFORE:", etree.tostring(elem))
 
     set_deep_meta_attr_node(elem, 'target-role', 'Stopped')
 
-    print "AFTER:", etree.tostring(elem)
+    print("AFTER:", etree.tostring(elem))
 
     assert len(elem.xpath(".//meta_attributes/nvpair[@name='target-role']")) == 1
 
 
-@with_setup(setup_func, teardown_func)
 def test_bnc878128():
     """
     L3: "crm configure show" displays XML information instead of typical crm output.
@@ -251,13 +242,12 @@ end="2014-05-17 17:56:11Z"/>
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'location cli-prefer-dummy-resource dummy-resource role=Started rule #uname eq x64-4 and date lt "2014-05-17 17:56:11Z"'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_order_without_score_kind():
     """
     Spec says order doesn't require score or kind to be set
@@ -267,14 +257,13 @@ def test_order_without_score_kind():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'order order-a-b a:promote b:start'
     assert data == exp
     assert obj.cli_use_validate()
 
 
 
-@with_setup(setup_func, teardown_func)
 def test_bnc878112():
     """
     crm configure group can hijack a cloned primitive (and then crash)
@@ -284,11 +273,10 @@ def test_bnc878112():
     obj2 = factory.create_object('group', 'g1', 'p1')
     assert obj2 is True
     obj3 = factory.create_object('group', 'g2', 'p1')
-    print obj3
+    print(obj3)
     assert obj3 is False
 
 
-@with_setup(setup_func, teardown_func)
 def test_copy_nvpairs():
     from crmsh.cibconfig import copy_nvpairs
 
@@ -303,8 +291,8 @@ def test_copy_nvpairs():
     </node>
     '''))
 
-    eq_(['stonith-enabled'], to.xpath('./nvpair/@name'))
-    eq_(['false'], to.xpath('./nvpair/@value'))
+    assert ['stonith-enabled'] == to.xpath('./nvpair/@name')
+    assert ['false'] == to.xpath('./nvpair/@value')
 
     copy_nvpairs(to, etree.fromstring('''
     <node>
@@ -312,11 +300,10 @@ def test_copy_nvpairs():
     </node>
     '''))
 
-    eq_(['stonith-enabled'], to.xpath('./nvpair/@name'))
-    eq_(['true'], to.xpath('./nvpair/@value'))
+    assert ['stonith-enabled'] == to.xpath('./nvpair/@name')
+    assert ['true'] == to.xpath('./nvpair/@value')
 
 
-@with_setup(setup_func, teardown_func)
 def test_pengine_test():
     xml = '''<primitive class="ocf" id="rsc1" provider="pacemaker" type="Dummy">
         <instance_attributes id="rsc1-instance_attributes-1">
@@ -339,13 +326,12 @@ def test_pengine_test():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'primitive rsc1 ocf:pacemaker:Dummy params rule 0: #cluster-name eq clusterA state="/var/run/Dummy-rsc1-clusterA" params rule 0: #cluster-name eq clusterB state="/var/run/Dummy-rsc1-clusterB" op monitor interval=10'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_tagset():
     xml = '''<primitive class="ocf" id="%s" provider="pacemaker" type="Dummy"/>'''
     tag = '''<tag id="t0"><obj_ref id="r1"/><obj_ref id="r2"/></tag>'''
@@ -356,7 +342,7 @@ def test_tagset():
     elems = factory.get_elems_on_tag("tag:t0")
     assert set(x.obj_id for x in elems) == set(['r1', 'r2'])
 
-@with_setup(setup_func, teardown_func)
+
 def test_ratrace():
     xml = '''<primitive class="ocf" id="%s" provider="pacemaker" type="Dummy"/>'''
     factory.create_from_node(etree.fromstring(xml % ('r1')))
@@ -376,7 +362,6 @@ def test_ratrace():
     assert set(obj.node.xpath('./operations/op/@name')) == set(['start', 'stop'])
 
 
-@with_setup(setup_func, teardown_func)
 def test_op_role():
     xml = '''<primitive class="ocf" id="rsc2" provider="pacemaker" type="Dummy">
         <operations>
@@ -387,13 +372,12 @@ def test_op_role():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'primitive rsc2 ocf:pacemaker:Dummy op monitor interval=10 role=Stopped'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_nvpair_no_value():
     xml = '''<primitive class="ocf" id="rsc3" provider="heartbeat" type="Dummy">
         <instance_attributes id="rsc3-instance_attributes-1">
@@ -406,13 +390,12 @@ def test_nvpair_no_value():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'primitive rsc3 Dummy params verbose verbase="" verbese=" "'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_delete_ticket():
     xml0 = '<primitive id="daa0" class="ocf" provider="heartbeat" type="Dummy"/>'
     xml1 = '<primitive id="daa1" class="ocf" provider="heartbeat" type="Dummy"/>'
@@ -433,7 +416,6 @@ def test_delete_ticket():
     assert factory.find_object('taa0') is not None
 
 
-@with_setup(setup_func, teardown_func)
 def test_quotes():
     """
     Parsing escaped quotes
@@ -448,13 +430,12 @@ def test_quotes():
     obj = factory.create_from_node(data)
     assert obj is not None
     data = obj.repr_cli(format_mode=-1)
-    print "OUTPUT:", data
+    print("OUTPUT:", data)
     exp = 'primitive q1 ocf:pacemaker:Dummy params state="foo\\"foo\\""'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_nodeattrs():
     """
     bug with parsing node attrs
@@ -478,7 +459,6 @@ def test_nodeattrs():
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_nodeattrs2():
     xml = """<node id="h04" uname="h04"> \
  <utilization id="h04-utilization"> \
@@ -498,7 +478,6 @@ def test_nodeattrs2():
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
 def test_group_constraint_location():
     """
     configuring a location constraint on a grouped resource is OK
@@ -512,7 +491,6 @@ def test_group_constraint_location():
     assert c and c.check_sanity() == 0
 
 
-@with_setup(setup_func, teardown_func)
 def test_group_constraint_colocation():
     """
     configuring a colocation constraint on a grouped resource is bad
@@ -525,7 +503,6 @@ def test_group_constraint_colocation():
     assert c and c.check_sanity() > 0
 
 
-@with_setup(setup_func, teardown_func)
 def test_group_constraint_colocation_rscset():
     """
     configuring a constraint on a grouped resource is bad
@@ -539,7 +516,6 @@ def test_group_constraint_colocation_rscset():
     assert c and c.check_sanity() > 0
 
 
-@with_setup(setup_func, teardown_func)
 def test_clone_constraint_colocation_rscset():
     """
     configuring a constraint on a cloned resource is bad
@@ -553,7 +529,6 @@ def test_clone_constraint_colocation_rscset():
     assert c and c.check_sanity() > 0
 
 
-@with_setup(setup_func, teardown_func)
 def test_existing_node_resource():
     factory.create_object('primitive', 'ha-one', 'Dummy')
 
@@ -572,7 +547,6 @@ def test_existing_node_resource():
     assert ok
 
 
-@with_setup(setup_func, teardown_func)
 def test_existing_node_resource_2():
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -592,7 +566,6 @@ def test_existing_node_resource_2():
     assert sorted(text.split('\n')) == sorted(text2.split('\n'))
 
 
-@with_setup(setup_func, teardown_func)
 def test_id_collision_breakage_1():
     from crmsh import clidisplay
 
@@ -600,7 +573,7 @@ def test_id_collision_breakage_1():
     assert obj is not None
     with clidisplay.nopretty():
         original_cib = obj.repr()
-    print original_cib
+    print(original_cib)
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -614,19 +587,18 @@ primitive p3 ocf:pacemaker:Dummy
 primitive st stonith:null params hostlist=node1
 clone c1 p1
 ms m1 p2
-property default-action-timeout=60s
+op_defaults timeout=60s
 """)
     assert ok
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
-    ok = obj.save("""property default-action-timeout=2m
+    ok = obj.save("""op_defaults timeout=2m
 node node1 \
     attributes mem=16G
 primitive st stonith:null \
     params hostlist='node1' \
-    meta description="some description here" \
-    op start requires=nothing \
+    meta description="some description here" requires=nothing \
     op monitor interval=60m
 primitive p1 ocf:heartbeat:Dummy \
     op monitor interval=60m \
@@ -658,7 +630,7 @@ primitive p1 ocf:heartbeat:Dummy \
 
     obj = cibconfig.mkset_obj("g1")
     with clidisplay.nopretty():
-        print obj.repr().strip()
+        print(obj.repr().strip())
         assert obj.repr().strip() == "group g1 p1 p3"
 
     obj = cibconfig.mkset_obj()
@@ -667,14 +639,13 @@ primitive p1 ocf:heartbeat:Dummy \
     assert ok
     obj = cibconfig.mkset_obj()
     with clidisplay.nopretty():
-        print "*** ORIGINAL"
-        print original_cib
-        print "*** NOW"
-        print obj.repr()
+        print("*** ORIGINAL")
+        print(original_cib)
+        print("*** NOW")
+        print(obj.repr())
         assert original_cib == obj.repr()
 
 
-@with_setup(setup_func, teardown_func)
 def test_id_collision_breakage_3():
     from crmsh import clidisplay
 
@@ -682,7 +653,7 @@ def test_id_collision_breakage_3():
     assert obj is not None
     with clidisplay.nopretty():
         original_cib = obj.repr()
-    print original_cib
+    print(original_cib)
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -691,11 +662,11 @@ primitive node1 Dummy params fake=something
     """)
     assert ok
 
-    print "** baseline"
+    print("** baseline")
     obj = cibconfig.mkset_obj()
     assert obj is not None
     with clidisplay.nopretty():
-        print obj.repr()
+        print(obj.repr())
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -703,7 +674,7 @@ primitive node1 Dummy params fake=something
     """, remove=False, method='update')
     assert ok
 
-    print "** end"
+    print("** end")
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -711,14 +682,13 @@ primitive node1 Dummy params fake=something
     assert ok
     obj = cibconfig.mkset_obj()
     with clidisplay.nopretty():
-        print "*** ORIGINAL"
-        print original_cib
-        print "*** NOW"
-        print obj.repr()
+        print("*** ORIGINAL")
+        print(original_cib)
+        print("*** NOW")
+        print(obj.repr())
         assert original_cib == obj.repr()
 
 
-@with_setup(setup_func, teardown_func)
 def test_id_collision_breakage_2():
     from crmsh import clidisplay
 
@@ -726,7 +696,7 @@ def test_id_collision_breakage_2():
     assert obj is not None
     with clidisplay.nopretty():
         original_cib = obj.repr()
-    print original_cib
+    print(original_cib)
 
     obj = cibconfig.mkset_obj()
     assert obj is not None
@@ -789,8 +759,7 @@ property cib-bootstrap-options: \
 	cluster-infrastructure=corosync \
 	cluster-name=hacluster \
 	stonith-enabled=true \
-	no-quorum-policy=ignore \
-	placement-strategy=balanced
+	no-quorum-policy=ignore
 rsc_defaults rsc-options: \
 	resource-stickiness=1 \
 	migration-threshold=3
@@ -806,14 +775,13 @@ op_defaults op-options: \
     assert ok
     obj = cibconfig.mkset_obj()
     with clidisplay.nopretty():
-        print "*** ORIGINAL"
-        print original_cib
-        print "*** NOW"
-        print obj.repr()
+        print("*** ORIGINAL")
+        print(original_cib)
+        print("*** NOW")
+        print(obj.repr())
         assert original_cib == obj.repr()
 
 
-@with_setup(setup_func, teardown_func)
 def test_bug_110():
     """
     configuring attribute-based fencing-topology
@@ -831,7 +799,6 @@ def test_bug_110():
             assert o.check_sanity() == 0
 
 
-@with_setup(setup_func, teardown_func)
 def test_reordering_resource_sets():
     """
     Can we reorder resource sets?
@@ -858,7 +825,6 @@ def test_reordering_resource_sets():
         assert "order o1 p4 p3 p2 p1" == obj2.repr().strip()
 
 
-@with_setup(setup_func, teardown_func)
 def test_bug959895():
     """
     Allow importing XML with cloned groups
@@ -872,9 +838,9 @@ def test_bug959895():
 """
     data = etree.fromstring(xml)
     obj = factory.create_from_node(data)
-    print etree.tostring(obj.node)
+    print(etree.tostring(obj.node))
     data = obj.repr_cli(format_mode=-1)
-    print data
+    print(data)
     exp = 'clone c-bug959895 g-bug959895'
     assert data == exp
     assert obj.cli_use_validate()
@@ -884,13 +850,11 @@ def test_bug959895():
         factory.commit = lambda *args: True
         from crmsh.ui_resource import set_deep_meta_attr
         set_deep_meta_attr("c-bug959895", "target-role", "Started")
-        eq_(['Started'],
-            obj.node.xpath('.//nvpair[@name="target-role"]/@value'))
+        assert ['Started'] == obj.node.xpath('.//nvpair[@name="target-role"]/@value')
     finally:
         factory.commit = commit_holder
 
 
-@with_setup(setup_func, teardown_func)
 def test_node_util_attr():
     """
     Handle node with utitilization before attributes correctly
@@ -907,16 +871,15 @@ def test_node_util_attr():
 
     data = etree.fromstring(xml)
     obj = factory.create_from_node(data)
-    print etree.tostring(obj.node)
+    print(etree.tostring(obj.node))
     data = obj.repr_cli(format_mode=-1)
-    print data
+    print(data)
     exp = 'node aberfeldy utilization cpu=2 memory=500 attributes standby=on'
     assert data == exp
     assert obj.cli_use_validate()
 
 
-@with_setup(setup_func, teardown_func)
-def test_dup_create():
+def test_dup_create_same_name():
     """
     Creating two objects with the same name
     """
@@ -926,7 +889,6 @@ def test_dup_create():
     assert not ok
 
 
-@with_setup(setup_func, teardown_func)
 def test_dup_create():
     """
     Creating property sets with unknown properties
