@@ -42,6 +42,37 @@ def _print(parser):
     print(parser.to_string())
 
 
+def test_query_status_exception():
+    with pytest.raises(ValueError) as err:
+        corosync.query_status("test")
+    assert str(err.value) == "Wrong type \"test\" to query status"
+
+
+@mock.patch('crmsh.corosync.query_ring_status')
+def test_query_status(mock_ring_status):
+    corosync.query_status("ring")
+    mock_ring_status.assert_called_once_with()
+
+
+@mock.patch('crmsh.utils.is_qdevice_configured')
+def test_query_qdevice_status_exception(mock_configured):
+    mock_configured.return_value = False
+    with pytest.raises(ValueError) as err:
+        corosync.query_qdevice_status()
+    assert str(err.value) == "QDevice/QNetd not configured!"
+    mock_configured.assert_called_once_with()
+
+
+@mock.patch('crmsh.utils.print_cluster_nodes')
+@mock.patch('crmsh.utils.get_stdout_or_raise_error')
+@mock.patch('crmsh.utils.is_qdevice_configured')
+def test_query_qdevice_status(mock_configured, mock_run, mock_print):
+    mock_configured.return_value = True
+    corosync.query_qdevice_status()
+    mock_run.assert_called_once_with("corosync-qdevice-tool -sv")
+    mock_print.assert_called_once_with()
+
+
 @mock.patch("crmsh.corosync.query_ring_status")
 def test_query_status_ring(mock_ring_status):
     corosync.query_status("ring")
@@ -324,6 +355,7 @@ class TestCorosyncParser(unittest.TestCase):
         # For some reason mock_search.assert_called_once_with does not work
         mock_search.assert_has_calls([mock.call("nodelist.node.ring[0-9]*_addr", "nodelist.node.ring0_addr")])
 
+    @mock.patch("crmsh.utils.str2file")
     @mock.patch("crmsh.corosync.make_section")
     @mock.patch("crmsh.corosync.get_values")
     @mock.patch("crmsh.corosync.make_value")
@@ -333,14 +365,13 @@ class TestCorosyncParser(unittest.TestCase):
     @mock.patch("crmsh.corosync.conf")
     @mock.patch("crmsh.corosync.find_configured_ip")
     def test_add_node_ucast(self, mock_find_ip, mock_conf, mock_open_file, mock_parser,
-            mock_free_id, mock_make_value, mock_get_values, mock_make_section):
+            mock_free_id, mock_make_value, mock_get_values, mock_make_section, mock_str2file):
         mock_parser_inst = mock.Mock()
         mock_conf.side_effect = ["corosync.conf", "corosync.conf"]
         mock_open_read = mock.mock_open(read_data="read data")
-        mock_open_write = mock.mock_open()
         mock_open_file.side_effect = [
                 mock_open_read.return_value,
-                mock_open_write.return_value]
+                ]
         mock_parser.return_value = mock_parser_inst
         mock_free_id.return_value = 2
         mock_make_value.side_effect = [["value1"], ["value2"]]
@@ -355,7 +386,6 @@ class TestCorosyncParser(unittest.TestCase):
         mock_find_ip.assert_called_once_with(['10.10.10.1'])
         mock_open_file.assert_has_calls([
             mock.call("corosync.conf"),
-            mock.call("corosync.conf", 'w')
             ])
         file_handle = mock_open_read.return_value.__enter__.return_value
         file_handle.read.assert_called_once_with()
@@ -381,8 +411,7 @@ class TestCorosyncParser(unittest.TestCase):
             ])
         mock_parser_inst.get.assert_called_once_with('quorum.device.model')
         mock_parser_inst.to_string.assert_called_once_with()
-        file_handle = mock_open_write.return_value.__enter__.return_value
-        file_handle.write.assert_called_once_with("string data")
+        mock_str2file.assert_called_once_with("string data", "corosync.conf")
 
     def test_add_node_nodelist(self):
         from crmsh.corosync import make_section, make_value, get_free_nodeid
@@ -465,13 +494,12 @@ class TestQDevice(unittest.TestCase):
         mock_installed.assert_called_once_with("corosync-qdevice")
 
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
-    def test_valid_attr_remote_exception(self, mock_installed, mock_getaddrinfo, mock_run, mock_ip_local):
+    def test_valid_attr_remote_exception(self, mock_installed, mock_getaddrinfo, mock_ping, mock_ip_local):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = True
 
         with self.assertRaises(ValueError) as err:
@@ -480,7 +508,7 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_ip_local.assert_called_once_with("10.10.10.123")
 
     @mock.patch("socket.getaddrinfo")
@@ -496,32 +524,15 @@ class TestQDevice(unittest.TestCase):
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("node.qnetd", None)
 
-    @mock.patch("crmsh.utils.get_stdout")
-    @mock.patch("socket.getaddrinfo")
-    @mock.patch("crmsh.utils.package_is_installed")
-    def test_valid_attr_unreachable_exception(self, mock_installed, mock_getaddrinfo, mock_run):
-        mock_installed.return_value = True
-        mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (1, None)
-
-        with self.assertRaises(ValueError) as err:
-            self.qdevice_with_hostname.valid_attr()
-        self.assertEqual("host \"node.qnetd\" is unreachable", str(err.exception))
-
-        mock_installed.assert_called_once_with("corosync-qdevice")
-        mock_getaddrinfo.assert_called_once_with("node.qnetd", None)
-        mock_run.assert_called_once_with("ping -c 1 node.qnetd")
-
     @mock.patch("crmsh.utils.check_port_open")
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_attr_ssh_service_exception(self, mock_installed, mock_getaddrinfo,
-            mock_run, mock_ip_local, mock_port_open):
+            mock_ping, mock_ip_local, mock_port_open):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = False
         mock_port_open.return_value = False
 
@@ -531,21 +542,20 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_port_open.assert_called_once_with("10.10.10.123", 22)
         mock_ip_local.assert_called_once_with("10.10.10.123")
 
     @mock.patch("crmsh.utils.valid_port")
     @mock.patch("crmsh.utils.check_port_open")
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_attr_invalid_port_exception(self, mock_installed, mock_getaddrinfo,
-            mock_run, mock_ip_local, mock_port_open, mock_valid_port):
+            mock_ping, mock_ip_local, mock_port_open, mock_valid_port):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = False
         mock_port_open.return_value = True
         mock_valid_port.return_value = False
@@ -556,7 +566,7 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_ip_local.assert_called_once_with("10.10.10.123")
         mock_port_open.assert_called_once_with("10.10.10.123", 22)
         mock_valid_port.assert_called_once_with(100)
@@ -565,14 +575,13 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.utils.valid_port")
     @mock.patch("crmsh.utils.check_port_open")
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_attr_invalid_nodeid_exception(self, mock_installed, mock_getaddrinfo,
-            mock_run, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
+            mock_ping, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = False
         mock_port_open.return_value = True
         mock_valid_port.return_value = True
@@ -585,7 +594,7 @@ class TestQDevice(unittest.TestCase):
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_ip_local.assert_called_once_with("10.10.10.123")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_port_open.assert_called_once_with("10.10.10.123", 22)
         mock_valid_port.assert_called_once_with(5403)
         mock_valid_nodeid.assert_called_once_with("wrong")
@@ -594,14 +603,13 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.utils.valid_port")
     @mock.patch("crmsh.utils.check_port_open")
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_attr_invalid_cmds_relative_path(self, mock_installed, mock_getaddrinfo,
-            mock_run, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
+            mock_ping, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = False
         mock_port_open.return_value = True
         mock_valid_port.return_value = True
@@ -613,7 +621,7 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_ip_local.assert_called_once_with("10.10.10.123")
         mock_port_open.assert_called_once_with("10.10.10.123", 22)
         mock_valid_port.assert_called_once_with(5403)
@@ -623,14 +631,13 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.utils.valid_port")
     @mock.patch("crmsh.utils.check_port_open")
     @mock.patch("crmsh.utils.InterfacesInfo.ip_in_local")
-    @mock.patch("crmsh.utils.get_stdout")
+    @mock.patch("crmsh.utils.ping_node")
     @mock.patch("socket.getaddrinfo")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_attr_invalid_cmds_not_exist(self, mock_installed, mock_getaddrinfo,
-            mock_run, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
+            mock_ping, mock_ip_local, mock_port_open, mock_valid_port, mock_valid_nodeid):
         mock_installed.return_value = True
         mock_getaddrinfo.return_value = [(None, ("10.10.10.123",)),]
-        mock_run.return_value = (0, None)
         mock_ip_local.return_value = False
         mock_port_open.return_value = True
         mock_valid_port.return_value = True
@@ -642,7 +649,7 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qdevice")
         mock_getaddrinfo.assert_called_once_with("10.10.10.123", None)
-        mock_run.assert_called_once_with("ping -c 1 10.10.10.123")
+        mock_ping.assert_called_once_with("10.10.10.123")
         mock_ip_local.assert_called_once_with("10.10.10.123")
         mock_port_open.assert_called_once_with("10.10.10.123", 22)
         mock_valid_port.assert_called_once_with(5403)
@@ -1183,31 +1190,29 @@ class TestQDevice(unittest.TestCase):
         mock_fetch_p12_from_cluster.assert_called_once_with()
         mock_import_p12_on_local.assert_called_once_with()
 
-    @mock.patch("os.fsync")
+    @mock.patch("crmsh.utils.str2file")
     @mock.patch("crmsh.corosync.make_section")
     @mock.patch("crmsh.corosync.Parser")
     @mock.patch("crmsh.corosync.conf")
     @mock.patch("builtins.open")
-    def test_write_qdevice_config(self, mock_open_file, mock_conf, mock_parser, mock_mksection, mock_fsync):
+    def test_write_qdevice_config(self, mock_open_file, mock_conf, mock_parser, mock_mksection, mock_str2file):
         open_return_value_1 = mock.mock_open(read_data=F2).return_value
-        open_return_value_2 = mock.mock_open().return_value
         mock_open_file.side_effect = [
             open_return_value_1,
-            open_return_value_2
         ]
         mock_mksection.side_effect = [
             ["device {", "}"],
             ["net {", "}"]
         ]
-        mock_conf.return_value = "/etc/corosync/corosync.conf"
+        mock_conf.side_effect = ["corosync.conf", "corosync.conf"]
         mock_instance = mock.Mock()
         mock_parser.return_value = mock_instance
+        mock_instance.to_string.return_value = "string data"
 
         self.qdevice_with_ip.write_qdevice_config()
 
         mock_open_file.assert_has_calls([
-            mock.call(mock_conf.return_value),
-            mock.call(mock_conf.return_value, 'w')
+            mock.call("corosync.conf"),
         ])
         mock_conf.assert_has_calls([mock.call(), mock.call()])
         mock_parser.assert_called_once_with(F2)
@@ -1230,38 +1235,32 @@ class TestQDevice(unittest.TestCase):
             mock.call('quorum.device', []),
             mock.call('quorum.device.net', [])
         ])
-        mock_fsync.assert_called_once_with(open_return_value_2)
-        open_return_value_2.write.assert_called_once_with(mock_instance.to_string())
-        open_return_value_2.flush.assert_called_once_with()
+        mock_str2file.assert_called_once_with("string data", "corosync.conf")
 
-    @mock.patch("os.fsync")
+    @mock.patch("crmsh.utils.str2file")
     @mock.patch("crmsh.corosync.Parser")
     @mock.patch("crmsh.corosync.conf")
     @mock.patch("builtins.open")
-    def test_remove_qdevice_config(self, mock_open_file, mock_conf, mock_parser, mock_fsync):
+    def test_remove_qdevice_config(self, mock_open_file, mock_conf, mock_parser, mock_str2file):
         open_return_value_1 = mock.mock_open(read_data=F4).return_value
-        open_return_value_2 = mock.mock_open().return_value
         mock_open_file.side_effect = [
             open_return_value_1,
-            open_return_value_2
         ]
-        mock_conf.return_value = "/etc/corosync/corosync.conf"
+        mock_conf.side_effect = ["corosync.conf", "corosync.conf"]
         mock_instance = mock.Mock()
         mock_parser.return_value = mock_instance
+        mock_instance.to_string.return_value = "string data"
 
         self.qdevice_with_ip.remove_qdevice_config()
 
         mock_open_file.assert_has_calls([
-            mock.call(mock_conf.return_value),
-            mock.call(mock_conf.return_value, 'w')
+            mock.call("corosync.conf"),
         ])
         mock_conf.assert_has_calls([mock.call(), mock.call()])
         mock_parser.assert_called_once_with(F4)
         mock_instance.remove.assert_called_once_with("quorum.device")
         mock_instance.to_string.assert_called_once_with()
-        mock_fsync.assert_called_once_with(open_return_value_2)
-        open_return_value_2.write.assert_called_once_with(mock_instance.to_string())
-        open_return_value_2.flush.assert_called_once_with()
+        mock_str2file.assert_called_once_with("string data", "corosync.conf")
 
     @mock.patch("crmsh.parallax.parallax_call")
     @mock.patch('crmsh.utils.list_cluster_nodes')
